@@ -20,6 +20,6 @@ from .display import (  # noqa: F401
     DisplayContext,
     Distribution,
 )
-from .file import BeancountFile, Entries, Options  # noqa: F401
+from .file import BeancountFile, Directives, Options  # noqa: F401
 from .query import QueryResult  # noqa: F401
 from .realize import RealAccount  # noqa: F401
